@@ -78,21 +78,13 @@ Fishconsole Project
 
 
 
-from Fishconsole import *
+
 
 __all__ = ["files","logs", "window", "helps", "fcv", "huitu", "Fishsys"]
 
-def help():
-    helps.帮助()
-
-def 帮助():
-    helps.帮助()
-
-def 版本号():
-    import pkg_resources  # 检查版本号的
-    return {"内部版本":fcv.version(),"pypi版本":pkg_resources.get_distribution('Fishconsole').version}
-
-
+def Fishconsole_project():
+    from Fishconsole import fcv
+    fcv.f_debug()
 
 
 
